cellphone_validator library
Classes
- Country
- A class representing a country with its associated properties.
- PhoneAutoDetectView
- A StatefulWidget that provides a UI for phone number input and validation.
- PhoneInputSelectorView
- PhoneInputSelectorView is a StatefulWidget that provides a UI for phone number validation.
- PhoneSummaryView
-
PhoneValidatorWidgetis a StatefulWidget that provides a UI for phone number validation. - PhoneValidator
- A class responsible for validating phone numbers based on a selected country.
Properties
- CellPhoneValidator → CellphoneValidatorCore
-
final